@@ -93,7 +93,8 @@ def write_result(text, max_height=None):
     """
     logger.info(f"Print result {type(text)}: {text}"[:200])
 
-    # only handle bytes or FormattedText, if it's str, convert to bytes
+    # this function only handle bytes or FormattedText
+    # if it's str, convert to bytes
     if isinstance(text, str):
         if config.decode:
             text = text.encode(config.decode)
@@ -107,9 +108,10 @@ def write_result(text, max_height=None):
             os.environ["LESS"] = "-SRX"
         # click.echo_via_pager only accepts str
         if config.decode:
-            text = text.decode()
+            text = text.decode(config.decode)
         else:
             text = text.decode()
+        # TODO current pager doesn't support colors
         click.echo_via_pager(text)
         return
 
@@ -117,9 +119,6 @@ def write_result(text, max_height=None):
         sys.stdout.buffer.write(text)
         sys.stdout.write("\n")
     else:
-        # TODO
-        # FormattedText to Stringbuffer
-        # click.echo_via_pager if output is too long
         print_formatted_text(text, end="", style=STYLE)
         print_formatted_text()
 
@@ -302,6 +301,7 @@ Use Redis URL to indicate connection(Can set with env `IREDIS_URL`), Example:
 SHELL = """Allow to run shell commands, default to True."""
 PAGER_HELP = """Using pager when output is too tall for your window, default to True."""
 
+
 # command line entry here...
 @click.command()
 @click.pass_context
@@ -439,7 +439,7 @@ def create_client(params):
     if dsn_from_url:
         # db from command lint options should be high priority
         db = db if db else dsn_from_url.db
-        client = Client(
+        return Client(
             host=dsn_from_url.host,
             port=dsn_from_url.port,
             db=db,
@@ -449,10 +449,8 @@ def create_client(params):
             username=dsn_from_url.username,
         )
     if params["socket"]:
-        client = Client(scheme="unix", path=params["socket"], db=db, password=password)
-    else:
-        client = Client(host=host, port=port, db=db, password=password)
-    return client
+        return Client(scheme="unix", path=params["socket"], db=db, password=password)
+    return Client(host=host, port=port, db=db, password=password)
 
 
 def main():
