@@ -1,3 +1,4 @@
+# noqa: F541
 """
 This module describes how to match a redis command to grammar token based on
 regex.
@@ -41,6 +42,7 @@ CONST = {
     "slowlogsub": "LEN RESET GET",
     "shutdown": "SAVE NOSAVE",
     "switch": "ON OFF SKIP",
+    "on_off": "ON OFF",
     "const_id": "ID",
     "addr": "ADDR",
     "skipme": "SKIPME",
@@ -79,6 +81,7 @@ CONST = {
     "overflow": "OVERFLOW",
     "overflow_option": "WRAP SAT FAIL",
     "version": "VERSION",
+    "schedule": "SCHEDULE",
     "graphevent": (
         "ACTIVE-DEFRAG-CYCLE "
         "AOF-FSYNC-ALWAYS "
@@ -111,6 +114,12 @@ CONST = {
         "ALL "
         "DEFAULT "
     ),
+    "redirect_const": "REDIRECT",
+    "prefix_const": "PREFIX",
+    "bcast_const": "BCAST",
+    "optin_const": "OPTIN",
+    "optout_const": "OPTOUT",
+    "noloop_const": "NOLOOP",
 }
 
 
@@ -132,12 +141,13 @@ VALID_NODE = r"\d+"
 NUM = r"\d+"
 NNUM = r"-?\+?\(?\[?(\d+|inf)"  # number cloud be negative
 _FLOAT = r"-?(\d|\.|e)+"
-LEXNUM = fr"(\[\w+)|(\(\w+)|(\+)|(-)"
+LEXNUM = r"(\[\w+)|(\(\w+)|(\+)|(-)"
 
 SLOT = fr"(?P<slot>{VALID_SLOT})"
 SLOTS = fr"(?P<slots>{VALID_SLOT}(\s+{VALID_SLOT})*)"
 NODE = fr"(?P<node>{VALID_NODE})"
 KEY = fr"(?P<key>{VALID_TOKEN})"
+PREFIX = fr"(?P<prefix>{VALID_TOKEN})"
 KEYS = fr"(?P<keys>{VALID_TOKEN}(\s+{VALID_TOKEN})*)"
 DESTINATION = fr"(?P<destination>{VALID_TOKEN})"
 NEWKEY = fr"(?P<newkey>{VALID_TOKEN})"
@@ -161,8 +171,8 @@ LONGITUDE = fr"(?P<longitude>{_FLOAT})"
 LATITUDE = fr"(?P<latitude>{_FLOAT})"
 CURSOR = fr"(?P<cursor>{NUM})"
 PARAMETER = fr"(?P<parameter>{VALID_TOKEN})"
-DOUBLE_LUA = fr'(?P<double_lua>[^"]*)'
-SINGLE_LUA = fr"(?P<single_lua>[^']*)"
+DOUBLE_LUA = r'(?P<double_lua>[^"]*)'
+SINGLE_LUA = r"(?P<single_lua>[^']*)"
 INTTYPE = r"(?P<inttype>(i|u)\d+)"
 # IP re copied from:
 # https://www.regular-expressions.info/ip.html
@@ -237,6 +247,7 @@ AGGREGATE = fr"(?P<aggregate>{c('aggregate')})"
 SLOWLOGSUB = fr"(?P<slowlogsub>{c('slowlogsub')})"
 SHUTDOWN = fr"(?P<shutdown>{c('shutdown')})"
 SWITCH = fr"(?P<switch>{c('switch')})"
+ON_OFF = fr"(?P<on_off>{c('on_off')})"
 CONST_ID = fr"(?P<const_id>{c('const_id')})"
 ADDR = fr"(?P<addr>{c('addr')})"
 SKIPME = fr"(?P<skipme>{c('skipme')})"
@@ -281,6 +292,14 @@ KEEPTTL = fr"(?P<keepttl>{c('keepttl')})"
 GRAPHEVENT = fr"(?P<graphevent>{c('graphevent')})"
 VERSION = fr"(?P<version>{c('version')})"
 SECTION = fr"(?P<section>{c('section')})"
+SCHEDULE = fr"(?P<schedule>{c('schedule')})"
+
+REDIRECT_CONST = fr"(?P<redirect_const>{c('redirect_const')})"
+PREFIX_CONST = fr"(?P<prefix_const>{c('prefix_const')})"
+BCAST_CONST = fr"(?P<bcast_const>{c('bcast_const')})"
+OPTIN_CONST = fr"(?P<optin_const>{c('optin_const')})"
+OPTOUT_CONST = fr"(?P<optout_const>{c('optout_const')})"
+NOLOOP_CONST = fr"(?P<noloop_const>{c('noloop_const')})"
 
 command_grammar = compile(COMMAND)
 
@@ -309,9 +328,10 @@ NEW_GRAMMAR = {
     "command_slot_count": fr"\s+ {SLOT} \s+ {COUNT} \s*",
     "command_key_samples_count": fr"""
         \s+ {KEY} \s+ {SAMPLES} \s+ {COUNT} \s*""",
-    "command": fr"\s*",
+    "command": r"\s*",
     "command_ip_port": fr"\s+ {IP} \s+ {PORT} \s*",
     "command_epoch": fr"\s+ {EPOCH} \s*",
+    "command_yes": fr"\s+ {YES} \s*",
     "command_sectionx": fr"(\s+ {SECTION})? \s*",
     "command_asyncx": fr"(\s+ {ASYNC})? \s*",
     "command_slot_slotsubcmd_nodex": fr"""
@@ -405,6 +425,7 @@ NEW_GRAMMAR = {
     "command_key_fieldvalues": fr"\s+ {KEY} (\s+ {FIELD} \s+ {VALUE})+ \s*",
     "command_slowlog": fr"\s+ {SLOWLOGSUB} \s+ {NUM} \s*",
     "command_switch": fr"\s+ {SWITCH} \s*",
+    "command_schedulex": fr"(\s+ {SCHEDULE})? \s*",
     "command_clientkill": fr"""
         (
             (\s+ {IP_PORT})|
@@ -508,6 +529,17 @@ NEW_GRAMMAR = {
     # before redis 5: lolwut 5 1
     # start from redis 6: lolwut VERSION 5 1
     "command_version": fr"(\s+ {VERSION} \s+ {VERSION_NUM})? (\s+ {ANY})? \s*",
+    "command_client_tracking": fr"""
+        \s+ {ON_OFF}
+        (
+            (\s+ {REDIRECT_CONST} \s+ {CLIENTID})|
+            (\s+ {PREFIX_CONST} \s+ {PREFIX})|
+            (\s+ {BCAST_CONST})|
+            (\s+ {OPTIN_CONST})|
+            (\s+ {OPTOUT_CONST})|
+            (\s+ {NOLOOP_CONST})
+        )*
+        \s*""",
 }
 
 pipeline = r"(?P<shellcommand>\|.*)?"
