@@ -25,37 +25,34 @@ class OutputRender:
     """Render redis output"""
 
     @staticmethod
-    def dynamic_render(command_name, response):
+    def get_render(command_name):
         """Dynamic render output due to command name."""
         command_upper = command_name.upper()
         callback_name = command2callback.get(command_upper)
-        # else, use defined callback
-        if callback_name is None:
-            logger.warning("unknown command %s", command_name)
-            return response
-
-        if not hasattr(OutputRender, callback_name):
-            # FIXME
-            # not implemented command, use no conversion
-            # this condition should be deleted finally
-            logger.warning(
-                "command `%s`'s callback %s is not implemented",
-                command_name,
-                callback_name,
-            )
-            return response
-
         callback = getattr(OutputRender, callback_name)
-        rendered = callback(response)
-        logger.info(f"[render] using {callback_name}, result: {rendered}")
-        return rendered
+        logger.info(
+            f"[render] Find callback {callback_name}, for command: {command_name}"
+        )
+        return callback
+
+    @staticmethod
+    def render_raw(value):
+        """
+        Render for all kinds, list, string, bulkstring, int
+
+        :return : bytes
+        """
+        if value is None:
+            return b""
+        if isinstance(value, bytes):
+            return value
+        if isinstance(value, int):
+            return str(value).encode()
+        if isinstance(value, list):
+            return _render_raw_list(value)
 
     @staticmethod
     def render_bulk_string(value):
-        if config.raw:
-            if value is None:
-                return b""
-            return value
         if value is None:
             return NIL
         return double_quotes(ensure_str(value))
@@ -78,16 +75,10 @@ class OutputRender:
         Render nested list.
         Items come as pairs.
         """
-        if config.raw:
-            return OutputRender.render_list(value)
         return FormattedText(_render_pair(value, 0))
 
     @staticmethod
     def render_int(value):
-        if config.raw:
-            if value is None:
-                return b""
-            return str(value).encode()
         if value is None:
             return NIL
         return FormattedText([("class:type", "(integer) "), ("", str(value))])
@@ -95,8 +86,6 @@ class OutputRender:
     @staticmethod
     def render_unixtime(value):
         rendered_int = OutputRender.render_int(value)
-        if config.raw:
-            return rendered_int
         explained_date = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(int(value)))
         rendered_int.extend(
             [
@@ -110,8 +99,6 @@ class OutputRender:
 
     @staticmethod
     def render_time(value):
-        if config.raw:
-            return OutputRender.render_list(value)
         unix_timestamp, millisecond = value[0].decode(), value[1].decode()
         explained_date = time.strftime(
             "%Y-%m-%d %H:%M:%S", time.localtime(int(unix_timestamp))
@@ -129,7 +116,7 @@ class OutputRender:
         return FormattedText(rendered)
 
     @staticmethod
-    def render_list(text):
+    def render_list(text, style="class:string"):
         """
         Render callback for redis Array Reply
         Note: Cloud be null in it.
@@ -142,9 +129,7 @@ class OutputRender:
                 str_item = ensure_str(item)
                 double_quoted = double_quotes(str_item)
                 str_items.append(double_quoted)
-        rendered = _render_list(text, str_items, "class:string")
-        if config.raw:
-            return rendered
+        rendered = _render_list(text, str_items, style)
         return FormattedText(rendered)
 
     @staticmethod
@@ -161,8 +146,6 @@ class OutputRender:
 
     @staticmethod
     def render_error(error_msg):
-        if config.raw:
-            return error_msg
         text = ensure_str(error_msg)
         return FormattedText([("class:type", "(error) "), ("class:error", text)])
 
@@ -172,8 +155,6 @@ class OutputRender:
         If response is b'OK', render simple string always with success color.
         If Error happend, error will be rendered by ``render_error``
         """
-        if config.raw:
-            return text
         if text is None:
             return NIL
         text = ensure_str(text)
@@ -186,22 +167,47 @@ class OutputRender:
 
         Response message should be "QUEUE" or Error.
         """
-        # FIXME raw
         text = ensure_str(text)
         return FormattedText([("class:queued", text)])
 
     @staticmethod
     def render_members(items):
-        if config.withscores:
-            if config.raw:
-                return _update_completer_then_render(items, "class:member")
-            return _update_completer_then_render_withscores(items)
-        return _update_completer_then_render(items, "class:member")
+        if not config.withscores:
+            return OutputRender.render_list(items, "class:member")
+
+        if not items:
+            return EMPTY_LIST
+        str_items = ensure_str(items)
+
+        members = [item for item in str_items[::2]]
+        scores = [item for item in str_items[1::2]]
+        logger.debug(f"[MEMBERS] {members}")
+        logger.debug(f"[SCORES] {scores}")
+        # render display
+        double_quoted = double_quotes(members)
+        index_width = len(str(len(double_quoted)))
+        score_width = max(len(score) for score in scores)
+        rendered = []
+        for index, item in enumerate(double_quoted):
+            index_const_width = f"{index+1:{index_width}})"
+            rendered.append(("", index_const_width))
+            # add a space between index and member
+            rendered.append(("", " "))
+            # add score
+            rendered.append(("class:integer", f"{scores[index]:{score_width}} "))
+            # add member
+            if item is None:
+                rendered.append(NIL_TUPLE)
+            else:
+                rendered.append(("class:member", item))
+
+            # add a newline for eachline
+            if index + 1 < len(double_quoted):
+                rendered.append(NEWLINE_TUPLE)
+        return FormattedText(rendered)
 
     @staticmethod
     def render_hash_pairs(response):
-        if config.raw:
-            return _update_completer_then_render(response, "class:field")
         # render hash pairs
         if not response:
             return EMPTY_LIST
@@ -233,8 +239,6 @@ class OutputRender:
 
     @staticmethod
     def render_slowlog(raw):
-        if config.raw:
-            return _render_raw_list(raw)
         fields = ["Slow log id", "Start at", "Running time(ms)", "Command"]
         if StrictVersion(config.version) > StrictVersion("4.0"):
             fields.extend(["Client IP and port", "Client name"])
@@ -272,8 +276,6 @@ class OutputRender:
         see: https://redis.io/topics/pubsub#format-of-pushed-messages
         """
         logger.info(raw)
-        if config.raw:
-            return OutputRender.render_list(raw)
         if raw[1] is None:
             raw[1] = "all"
         mtype, *channel, message = ensure_str(raw)
@@ -290,7 +292,7 @@ class OutputRender:
 
     @staticmethod
     def command_keys(items):
-        return _update_completer_then_render(items, "class:key")
+        return OutputRender.render_list(items, "class:key")
 
     @staticmethod
     def command_scan(response):
@@ -314,7 +316,7 @@ class OutputRender:
 
     @staticmethod
     def command_hkeys(response):
-        return _update_completer_then_render(response, "class:field")
+        return OutputRender.render_list(response, "class:field")
 
     @staticmethod
     def render_bytes(response):
@@ -343,9 +345,6 @@ def _render_list(byte_items, str_items, style=None, pre_space=0):
     """Complute the newline/number-width/lineno,
     render list to FormattedText
     """
-    if config.raw:
-        return _render_raw_list(byte_items)
-
     if not str_items:
         return EMPTY_LIST
 
@@ -377,8 +376,6 @@ def _render_list(byte_items, str_items, style=None, pre_space=0):
 
 def _render_scan(render_response, response):
     cursor, responses = response
-    if config.raw:
-        return b"\n".join([cursor, render_response(responses)])
 
     rendered = [
         ("class:type", "(cursor) "),
@@ -406,49 +403,5 @@ def _render_pair(pairs, indent):
     return rendered[:-1]  # remove last newline
 
 
-def _update_completer_then_render(items, style):
-    """
-    """
-    str_items = ensure_str(items)
-    double_quoted = double_quotes(str_items)
-    rendered = _render_list(items, double_quoted, style)
-    if config.raw:
-        return rendered
-    return FormattedText(rendered)
-
-
-def _update_completer_then_render_withscores(items):
-    if not items:
-        return EMPTY_LIST
-    str_items = ensure_str(items)
-
-    members = [item for item in str_items[::2]]
-    scores = [item for item in str_items[1::2]]
-    logger.debug(f"[MEMBERS] {members}")
-    logger.debug(f"[SCORES] {scores}")
-    # render display
-    double_quoted = double_quotes(members)
-    index_width = len(str(len(double_quoted)))
-    score_width = max(len(score) for score in scores)
-    rendered = []
-    for index, item in enumerate(double_quoted):
-        index_const_width = f"{index+1:{index_width}})"
-        rendered.append(("", index_const_width))
-        # add a space between index and member
-        rendered.append(("", " "))
-        # add score
-        rendered.append(("class:integer", f"{scores[index]:{score_width}} "))
-        # add member
-        if item is None:
-            rendered.append(NIL_TUPLE)
-        else:
-            rendered.append(("class:member", item))
-
-        # add a newline for eachline
-        if index + 1 < len(double_quoted):
-            rendered.append(NEWLINE_TUPLE)
-    return FormattedText(rendered)
-
-
 # TODO
 # special list render, bzpopmax, key-value pair
